<?xml version="1.0" encoding="UTF-8"?>
<!--
   Copyright 2009 Anyware Services

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
   -->
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:i18n="http://apache.org/cocoon/i18n/2.1"
                xmlns:xalan="http://xml.apache.org/xalan"
                exclude-result-prefixes="xalan">
	
    <xsl:import href="resource://org/ametys/runtime/kernel/stylesheets/ui.xsl"/>
    
    <xsl:param name="contextPath"/>
    <xsl:param name="workspaceName"/>
    <xsl:param name="workspaceURI"/>
    
    <xsl:variable name="workspaceContext"><xsl:value-of select="$contextPath"/><xsl:value-of select="$workspaceURI"/></xsl:variable>
    
    <xsl:template name="administrator-css">
		<style type="text/css">
			#top { background-image: url('<xsl:value-of select="$workspaceContext"/>/resources/img/top_<i18n:text i18n:key="KERNEL_LANGUAGE_CODE" i18n:catalogue="kernel"/>.jpg'); } 
		</style>
    </xsl:template>

	<xsl:template match="/">
		<html>
			<!-- ****** HEAD ****** -->
			<head> 
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
				<meta http-equiv="X-UA-Compatible" content="IE=9" />
				<title>
					<i18n:text i18n:catalogue="workspace.{$workspaceName}" i18n:key="WORKSPACE_ADMIN_LABEL_SHORT"/>
					<xsl:text> </xsl:text>
					<i18n:text i18n:catalogue="application" i18n:key="APPLICATION_PRODUCT_LABEL"/>
				</title>  
				
                <link rel="icon" type="image/gif" href="{$contextPath}/kernel/resources/img/runtime_favico.gif" />
                <link rel="shortcut icon" type="image/x-icon" href="{$contextPath}/kernel/resources/img/runtime_favico.ico" />
                <link rel="stylesheet" href="{$contextPath}/kernel/resources/css/homepage/view.css" type="text/css"/>
				<link rel="stylesheet" href="{$workspaceContext}/resources/css/admin.css" type="text/css"/>
				<link rel="stylesheet" href="{$workspaceContext}/resources/css/panel.css" type="text/css"/>
		        
		        <xsl:call-template name="administrator-css"/>
		        
		        <xsl:call-template name="workspace-ui-load"/>
				
                <xsl:call-template name="workspace-head"/>
                
                <xsl:call-template name="workspace-head-scripts"/>
                
                <xsl:comment>[if lt IE 7]&gt;
						&lt;script defer="defer" type="text/javascript" src="<xsl:value-of select="$workspaceContext"/>/resources/js/pngfix.js">&lt;/script&gt;
				&lt;![endif]</xsl:comment>

				<xsl:call-template name="workspace-script"/>
			</head>
		
			<!-- ****** BODY ****** -->
			<body>
				<xsl:call-template name="workspace-body"/>
				
				<noscript><div id="no-script"><i18n:text i18n:key="WORKSPACE_ADMIN_ERROR_NOJS" i18n:catalogue="workspace.{$workspaceName}"/></div></noscript>
			</body>
		</html>		
	</xsl:template>
	
	<xsl:template name="workspace-ui-load">
		<!-- loading ui library -->
        <xsl:call-template name="ui-load">
            <xsl:with-param name="pluginsDirectContext" select="concat($workspaceContext, '/plugins')"/>
            <xsl:with-param name="pluginsWrappedContext" select="concat($workspaceContext, '/_plugins')"/>
        </xsl:call-template>
        
        <!-- Check navigator is supported -->
        <xsl:call-template name="ui-tools-load">
            <xsl:with-param name="bad-navigator-redirection"><xsl:value-of select="$workspaceContext"/>/public/navigator.html</xsl:with-param>

            <xsl:with-param name="accept-ie-6">true</xsl:with-param>
            <xsl:with-param name="accept-ie-7">true</xsl:with-param>
            <xsl:with-param name="accept-ie-8">true</xsl:with-param>
            <xsl:with-param name="accept-ie-9">true</xsl:with-param>
            <xsl:with-param name="accept-ff-1.0">false</xsl:with-param>
            <xsl:with-param name="accept-ff-1.5">true</xsl:with-param>
            <xsl:with-param name="accept-ff-2.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-3.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-3.5">true</xsl:with-param>
            <xsl:with-param name="accept-ff-3.6">true</xsl:with-param>
            <xsl:with-param name="accept-ff-4.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-5.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-6.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-7.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-8.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-9.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-10.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-11.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-12.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-13.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-14.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-15.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-16.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-17.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-18.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-19.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-20.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-21.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-22.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-23.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-24.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-25.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-26.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-27.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-28.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-29.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-30.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-31.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-32.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-33.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-34.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-35.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-36.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-37.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-38.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-39.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-40.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-41.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-42.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-43.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-44.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-45.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-46.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-47.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-48.0">true</xsl:with-param>
            <xsl:with-param name="accept-ff-49.0">true</xsl:with-param>
            <xsl:with-param name="accept-sa-3">true</xsl:with-param>
            <xsl:with-param name="accept-sa-4">true</xsl:with-param>
            <xsl:with-param name="accept-sa-5.0">true</xsl:with-param>
            <xsl:with-param name="accept-sa-5.1">true</xsl:with-param>
            <xsl:with-param name="accept-op-9">true</xsl:with-param>
            <xsl:with-param name="accept-op-10">true</xsl:with-param>
            <xsl:with-param name="accept-ch-1">true</xsl:with-param>
            <xsl:with-param name="accept-ch-2">true</xsl:with-param>
            <xsl:with-param name="accept-ch-3">true</xsl:with-param>
            <xsl:with-param name="accept-ch-4">true</xsl:with-param>
            <xsl:with-param name="accept-ch-5">true</xsl:with-param>
            <xsl:with-param name="accept-ch-6">true</xsl:with-param>
            <xsl:with-param name="accept-ch-7">true</xsl:with-param>
            <xsl:with-param name="accept-ch-8">true</xsl:with-param>
            <xsl:with-param name="accept-ch-9">true</xsl:with-param>
            <xsl:with-param name="accept-ch-10">true</xsl:with-param>
            <xsl:with-param name="accept-ch-11">true</xsl:with-param>
            <xsl:with-param name="accept-ch-12">true</xsl:with-param>
            <xsl:with-param name="accept-ch-13">true</xsl:with-param>
            <xsl:with-param name="accept-ch-14">true</xsl:with-param>
            <xsl:with-param name="accept-ch-14">true</xsl:with-param>
            <xsl:with-param name="accept-ch-15">true</xsl:with-param>
            <xsl:with-param name="accept-ch-16">true</xsl:with-param>
            <xsl:with-param name="accept-ch-17">true</xsl:with-param>
            <xsl:with-param name="accept-ch-18">true</xsl:with-param>
            <xsl:with-param name="accept-ch-19">true</xsl:with-param>
            <xsl:with-param name="accept-ch-20">true</xsl:with-param>
            <xsl:with-param name="accept-ch-21">true</xsl:with-param>
            <xsl:with-param name="accept-ch-22">true</xsl:with-param>
            <xsl:with-param name="accept-ch-23">true</xsl:with-param>
            <xsl:with-param name="accept-ch-24">true</xsl:with-param>
            <xsl:with-param name="accept-ch-25">true</xsl:with-param>
            <xsl:with-param name="accept-ch-26">true</xsl:with-param>
            <xsl:with-param name="accept-ch-27">true</xsl:with-param>
            <xsl:with-param name="accept-ch-28">true</xsl:with-param>
            <xsl:with-param name="accept-ch-29">true</xsl:with-param>
            <xsl:with-param name="accept-ch-30">true</xsl:with-param>
            <xsl:with-param name="accept-ch-31">true</xsl:with-param>
            <xsl:with-param name="accept-ch-32">true</xsl:with-param>
            <xsl:with-param name="accept-ch-33">true</xsl:with-param>
            <xsl:with-param name="accept-ch-34">true</xsl:with-param>
            <xsl:with-param name="accept-ch-35">true</xsl:with-param>
            <xsl:with-param name="accept-ch-36">true</xsl:with-param>
            <xsl:with-param name="accept-ch-37">true</xsl:with-param>
            <xsl:with-param name="accept-ch-38">true</xsl:with-param>
            <xsl:with-param name="accept-ch-39">true</xsl:with-param>
            <xsl:with-param name="accept-ch-40">true</xsl:with-param>
            <xsl:with-param name="accept-ch-41">true</xsl:with-param>
            <xsl:with-param name="accept-ch-42">true</xsl:with-param>
            <xsl:with-param name="accept-ch-43">true</xsl:with-param>
            <xsl:with-param name="accept-ch-44">true</xsl:with-param>
            <xsl:with-param name="accept-ch-45">true</xsl:with-param>
            <xsl:with-param name="accept-ch-46">true</xsl:with-param>
            <xsl:with-param name="accept-ch-47">true</xsl:with-param>
            <xsl:with-param name="accept-ch-48">true</xsl:with-param>
            <xsl:with-param name="accept-ch-49">true</xsl:with-param>
            <xsl:with-param name="accept-ch-50">true</xsl:with-param>
            <xsl:with-param name="accept-ch-51">true</xsl:with-param>
            <xsl:with-param name="accept-ch-52">true</xsl:with-param>
            <xsl:with-param name="accept-ch-53">true</xsl:with-param>
            <xsl:with-param name="accept-ch-54">true</xsl:with-param>
            <xsl:with-param name="use-css-component">false</xsl:with-param>
            <xsl:with-param name="use-js-component">false</xsl:with-param>
            <xsl:with-param name="debug-mode">true</xsl:with-param>
    	</xsl:call-template>
	</xsl:template>
    
    <xsl:template name="workspace-head-scripts">
    	<script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/Fieldset.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/ActionsPanel.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/Action.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/TextPanel.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/NavigationPanel.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/NavigationItem.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/DesktopPanel.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/DesktopCategory.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/DesktopItem.js"></script>
        
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/DockItem.js"></script>
        <script type="text/javascript" src="{$workspaceContext}/resources/js/org/ametys/AdminTools.js"></script>

        <script type="text/javascript">
            Ext.QuickTips.init();
        </script>
        
        <script type="text/javascript" src="{$contextPath}/kernel/resources/js/org/ametys/runtime/HomePage.js"><xsl:comment>//empty</xsl:comment></script>
                
        <script type="text/javascript">
        	<xsl:if test="/Admin/Versions/Component|/Plugins/Versions/Component">
              	
              	var data = {versions : []};
              	<xsl:for-each select="/Admin/Versions/Component|/Plugins/Versions/Component">
              		data.versions.push({
              			name : "<xsl:value-of select="Name"/>",
              			version: "<xsl:choose><xsl:when test="Version"><xsl:value-of select="Version"/></xsl:when><xsl:otherwise><i18n:text i18n:key="WORKSPACE_ADMIN_VERSION_UNKNOWN" i18n:catalogue="workspace.{$workspaceName}"/></xsl:otherwise></xsl:choose>",
              			date : "<xsl:if test="Date">&#160;<i18n:text i18n:key="WORKSPACE_ADMIN_VERSION_DATED" i18n:catalogue="workspace.{$workspaceName}"/>&#160;<xsl:value-of select="Date"/>&#160;<i18n:text i18n:key="WORKSPACE_ADMIN_VERSION_DATEDTIME" i18n:catalogue="workspace.{$workspaceName}"/>&#160;<xsl:value-of select="Time"/></xsl:if><xsl:if test="position() != last()">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:if>"
              		});
              	</xsl:for-each>
              	org.ametys.runtime.HomePage._tplFooter = new Ext.XTemplate (
              		'&lt;div id="versions"&gt;',
              		'&lt;tpl for="versions"&gt;',
              		'&lt;span class="title"&gt;{name}&#160;-&#160;&lt;/span&gt;',
              		'{version}',
              		'{date}',
              		'&lt;/tpl&gt;',
              		'&lt;/div&gt;'
              	);
              	
              	org.ametys.runtime.HomePage._tplFooter.compile();
              	
            	org.ametys.runtime.HomePage.drawFooterPanel = function ()
				{
					return new org.ametys.HtmlContainer (
					{
	   					border: false,
	   					html : '',
	   					listeners: {
					        'render' : function(p) {
					        	org.ametys.runtime.HomePage._tplFooter.overwrite(p.getEl(), data);
					        }
	    				}
	
					});
				}
			</xsl:if>
    	</script>
    </xsl:template>
    
    <xsl:template name="workspace-head"/>
    <xsl:template name="workspace-title"/>
    <xsl:template name="workspace-body"/>
    <xsl:template name="workspace-script"/>
	
</xsl:stylesheet>
	